package com.bumptech.glide.gifdecoder;

import android.graphics.Bitmap;
import android.os.Build;
import android.util.Log;
import androidx.fragment.app.FragmentTransaction;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.nio.ByteBuffer;
import java.nio.ByteOrder;
import java.util.Arrays;
import java.util.Iterator;
/* loaded from: classes14.dex */
public class GifDecoder {
    private static final Bitmap.Config BITMAP_CONFIG = Bitmap.Config.ARGB_8888;
    private static final int DISPOSAL_BACKGROUND = 2;
    private static final int DISPOSAL_NONE = 1;
    private static final int DISPOSAL_PREVIOUS = 3;
    private static final int DISPOSAL_UNSPECIFIED = 0;
    private static final int INITIAL_FRAME_POINTER = -1;
    private static final int MAX_STACK_SIZE = 4096;
    private static final int NULL_CODE = -1;
    public static final int STATUS_FORMAT_ERROR = 1;
    public static final int STATUS_OK = 0;
    public static final int STATUS_OPEN_ERROR = 2;
    public static final int STATUS_PARTIAL_DECODE = 3;
    private static final String TAG = "GifDecoder";
    private int[] act;
    private BitmapProvider bitmapProvider;
    private byte[] data;
    private int framePointer;
    private byte[] mainPixels;
    private int[] mainScratch;
    private GifHeaderParser parser;
    private byte[] pixelStack;
    private short[] prefix;
    private Bitmap previousImage;
    private ByteBuffer rawData;
    private boolean savePrevious;
    private int status;
    private byte[] suffix;
    private final byte[] block = new byte[256];
    private GifHeader header = new GifHeader();

    /* loaded from: classes14.dex */
    public interface BitmapProvider {
        Bitmap obtain(int i2, int i3, Bitmap.Config config);

        void release(Bitmap bitmap);
    }

    public GifDecoder(BitmapProvider bitmapProvider) {
        this.bitmapProvider = bitmapProvider;
    }

    public int getWidth() {
        return this.header.width;
    }

    public int getHeight() {
        return this.header.height;
    }

    public byte[] getData() {
        return this.data;
    }

    public int getStatus() {
        return this.status;
    }

    public void advance() {
        this.framePointer = (this.framePointer + 1) % this.header.frameCount;
    }

    public int getDelay(int i2) {
        if (i2 < 0 || i2 >= this.header.frameCount) {
            return -1;
        }
        return this.header.frames.get(i2).delay;
    }

    public int getNextDelay() {
        int i2;
        if (this.header.frameCount <= 0 || (i2 = this.framePointer) < 0) {
            return -1;
        }
        return getDelay(i2);
    }

    public int getFrameCount() {
        return this.header.frameCount;
    }

    public int getCurrentFrameIndex() {
        return this.framePointer;
    }

    public void resetFrameIndex() {
        this.framePointer = -1;
    }

    public int getLoopCount() {
        return this.header.loopCount;
    }

    public synchronized Bitmap getNextFrame() {
        if (this.header.frameCount <= 0 || this.framePointer < 0) {
            String str = TAG;
            if (Log.isLoggable(str, 3)) {
                Log.d(str, "unable to decode frame, frameCount=" + this.header.frameCount + " framePointer=" + this.framePointer);
            }
            this.status = 1;
        }
        int i2 = this.status;
        if (i2 != 1 && i2 != 2) {
            int i3 = 0;
            this.status = 0;
            GifFrame gifFrame = this.header.frames.get(this.framePointer);
            int i4 = this.framePointer - 1;
            GifFrame gifFrame2 = i4 >= 0 ? this.header.frames.get(i4) : null;
            if (gifFrame.lct == null) {
                this.act = this.header.gct;
            } else {
                this.act = gifFrame.lct;
                if (this.header.bgIndex == gifFrame.transIndex) {
                    this.header.bgColor = 0;
                }
            }
            if (gifFrame.transparency) {
                int i5 = this.act[gifFrame.transIndex];
                this.act[gifFrame.transIndex] = 0;
                i3 = i5;
            }
            if (this.act == null) {
                String str2 = TAG;
                if (Log.isLoggable(str2, 3)) {
                    Log.d(str2, "No Valid Color Table");
                }
                this.status = 1;
                return null;
            }
            Bitmap pixels = setPixels(gifFrame, gifFrame2);
            if (gifFrame.transparency) {
                this.act[gifFrame.transIndex] = i3;
            }
            return pixels;
        }
        String str3 = TAG;
        if (Log.isLoggable(str3, 3)) {
            Log.d(str3, "Unable to decode frame, status=" + this.status);
        }
        return null;
    }

    public int read(InputStream inputStream, int i2) {
        if (inputStream != null) {
            try {
                ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream(i2 > 0 ? i2 + 4096 : 16384);
                byte[] bArr = new byte[16384];
                while (true) {
                    int read = inputStream.read(bArr, 0, 16384);
                    if (read == -1) {
                        break;
                    }
                    byteArrayOutputStream.write(bArr, 0, read);
                }
                byteArrayOutputStream.flush();
                read(byteArrayOutputStream.toByteArray());
            } catch (IOException e) {
                Log.w(TAG, "Error reading data from stream", e);
            }
        } else {
            this.status = 2;
        }
        if (inputStream != null) {
            try {
                inputStream.close();
            } catch (IOException e2) {
                Log.w(TAG, "Error closing stream", e2);
            }
        }
        return this.status;
    }

    public void clear() {
        this.header = null;
        this.data = null;
        this.mainPixels = null;
        this.mainScratch = null;
        Bitmap bitmap = this.previousImage;
        if (bitmap != null) {
            this.bitmapProvider.release(bitmap);
        }
        this.previousImage = null;
        this.rawData = null;
    }

    public void setData(GifHeader gifHeader, byte[] bArr) {
        this.header = gifHeader;
        this.data = bArr;
        this.status = 0;
        this.framePointer = -1;
        ByteBuffer wrap = ByteBuffer.wrap(bArr);
        this.rawData = wrap;
        wrap.rewind();
        this.rawData.order(ByteOrder.LITTLE_ENDIAN);
        this.savePrevious = false;
        Iterator<GifFrame> it = gifHeader.frames.iterator();
        while (true) {
            if (!it.hasNext()) {
                break;
            } else if (it.next().dispose == 3) {
                this.savePrevious = true;
                break;
            }
        }
        this.mainPixels = new byte[gifHeader.width * gifHeader.height];
        this.mainScratch = new int[gifHeader.width * gifHeader.height];
    }

    private GifHeaderParser getHeaderParser() {
        if (this.parser == null) {
            this.parser = new GifHeaderParser();
        }
        return this.parser;
    }

    public int read(byte[] bArr) {
        this.data = bArr;
        this.header = getHeaderParser().setData(bArr).parseHeader();
        if (bArr != null) {
            ByteBuffer wrap = ByteBuffer.wrap(bArr);
            this.rawData = wrap;
            wrap.rewind();
            this.rawData.order(ByteOrder.LITTLE_ENDIAN);
            this.mainPixels = new byte[this.header.width * this.header.height];
            this.mainScratch = new int[this.header.width * this.header.height];
            this.savePrevious = false;
            Iterator<GifFrame> it = this.header.frames.iterator();
            while (true) {
                if (!it.hasNext()) {
                    break;
                } else if (it.next().dispose == 3) {
                    this.savePrevious = true;
                    break;
                }
            }
        }
        return this.status;
    }

    /* JADX WARN: Removed duplicated region for block: B:22:0x004c  */
    /* JADX WARN: Removed duplicated region for block: B:56:0x00ba  */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    private Bitmap setPixels(GifFrame gifFrame, GifFrame gifFrame2) {
        int i2;
        int i3;
        Bitmap bitmap;
        int i4 = this.header.width;
        int i5 = this.header.height;
        int[] iArr = this.mainScratch;
        int i6 = 0;
        if (gifFrame2 != null && gifFrame2.dispose > 0) {
            if (gifFrame2.dispose == 2) {
                Arrays.fill(iArr, !gifFrame.transparency ? this.header.bgColor : 0);
            } else if (gifFrame2.dispose == 3 && (bitmap = this.previousImage) != null) {
                i2 = 2;
                bitmap.getPixels(iArr, 0, i4, 0, 0, i4, i5);
                decodeBitmapData(gifFrame);
                int i7 = 8;
                int i8 = 0;
                int i9 = 1;
                while (i6 < gifFrame.ih) {
                    if (gifFrame.interlace) {
                        if (i8 >= gifFrame.ih) {
                            i9++;
                            if (i9 == i2) {
                                i8 = 4;
                            } else if (i9 == 3) {
                                i7 = 4;
                                i8 = 2;
                            } else if (i9 == 4) {
                                i7 = 2;
                                i8 = 1;
                            }
                        }
                        i3 = i8 + i7;
                    } else {
                        i3 = i8;
                        i8 = i6;
                    }
                    int i10 = i8 + gifFrame.iy;
                    if (i10 < this.header.height) {
                        int i11 = i10 * this.header.width;
                        int i12 = gifFrame.ix + i11;
                        int i13 = gifFrame.iw + i12;
                        if (this.header.width + i11 < i13) {
                            i13 = this.header.width + i11;
                        }
                        int i14 = gifFrame.iw * i6;
                        while (i12 < i13) {
                            int i15 = i14 + 1;
                            int i16 = this.act[this.mainPixels[i14] & 255];
                            if (i16 != 0) {
                                iArr[i12] = i16;
                            }
                            i12++;
                            i14 = i15;
                        }
                    }
                    i6++;
                    i8 = i3;
                }
                if (this.savePrevious && (gifFrame.dispose == 0 || gifFrame.dispose == 1)) {
                    if (this.previousImage == null) {
                        this.previousImage = getNextBitmap();
                    }
                    this.previousImage.setPixels(iArr, 0, i4, 0, 0, i4, i5);
                }
                Bitmap nextBitmap = getNextBitmap();
                nextBitmap.setPixels(iArr, 0, i4, 0, 0, i4, i5);
                return nextBitmap;
            }
        }
        i2 = 2;
        decodeBitmapData(gifFrame);
        int i72 = 8;
        int i82 = 0;
        int i92 = 1;
        while (i6 < gifFrame.ih) {
        }
        if (this.savePrevious) {
            if (this.previousImage == null) {
            }
            this.previousImage.setPixels(iArr, 0, i4, 0, 0, i4, i5);
        }
        Bitmap nextBitmap2 = getNextBitmap();
        nextBitmap2.setPixels(iArr, 0, i4, 0, 0, i4, i5);
        return nextBitmap2;
    }

    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Removed duplicated region for block: B:61:0x0138 A[LOOP:5: B:60:0x0136->B:61:0x0138, LOOP_END] */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    private void decodeBitmapData(GifFrame gifFrame) {
        int i2;
        int i3;
        short s;
        if (gifFrame != null) {
            this.rawData.position(gifFrame.bufferFrameStart);
        }
        int i4 = gifFrame == null ? this.header.width * this.header.height : gifFrame.ih * gifFrame.iw;
        byte[] bArr = this.mainPixels;
        if (bArr == null || bArr.length < i4) {
            this.mainPixels = new byte[i4];
        }
        if (this.prefix == null) {
            this.prefix = new short[4096];
        }
        if (this.suffix == null) {
            this.suffix = new byte[4096];
        }
        if (this.pixelStack == null) {
            this.pixelStack = new byte[FragmentTransaction.TRANSIT_FRAGMENT_OPEN];
        }
        int read = read();
        int i5 = 1;
        int i6 = 1 << read;
        int i7 = i6 + 1;
        int i8 = i6 + 2;
        int i9 = read + 1;
        int i10 = (1 << i9) - 1;
        for (int i11 = 0; i11 < i6; i11++) {
            this.prefix[i11] = 0;
            this.suffix[i11] = (byte) i11;
        }
        int i12 = -1;
        int i13 = i9;
        int i14 = i8;
        int i15 = i10;
        int i16 = 0;
        int i17 = 0;
        int i18 = 0;
        int i19 = 0;
        int i20 = 0;
        int i21 = 0;
        int i22 = -1;
        int i23 = 0;
        int i24 = 0;
        while (true) {
            if (i16 >= i4) {
                break;
            }
            if (i17 == 0) {
                i17 = readBlock();
                if (i17 <= 0) {
                    this.status = 3;
                    break;
                }
                i18 = 0;
            }
            i20 += (this.block[i18] & 255) << i19;
            i19 += 8;
            i18 += i5;
            i17 += i12;
            int i25 = i14;
            int i26 = i13;
            int i27 = i22;
            int i28 = i23;
            while (i19 >= i26) {
                int i29 = i20 & i15;
                i20 >>= i26;
                i19 -= i26;
                if (i29 != i6) {
                    if (i29 > i25) {
                        i2 = i9;
                        this.status = 3;
                    } else {
                        i2 = i9;
                        if (i29 != i7) {
                            if (i27 == -1) {
                                this.pixelStack[i24] = this.suffix[i29];
                                i27 = i29;
                                i28 = i27;
                                i24++;
                                i9 = i2;
                            } else {
                                if (i29 >= i25) {
                                    i3 = i7;
                                    this.pixelStack[i24] = (byte) i28;
                                    s = i27;
                                    i24++;
                                } else {
                                    i3 = i7;
                                    s = i29;
                                }
                                while (s >= i6) {
                                    this.pixelStack[i24] = this.suffix[s];
                                    s = this.prefix[s];
                                    i24++;
                                    i6 = i6;
                                }
                                int i30 = i6;
                                byte[] bArr2 = this.suffix;
                                int i31 = bArr2[s] & 255;
                                int i32 = i24 + 1;
                                int i33 = i8;
                                byte b = (byte) i31;
                                this.pixelStack[i24] = b;
                                if (i25 < 4096) {
                                    this.prefix[i25] = (short) i27;
                                    bArr2[i25] = b;
                                    i25++;
                                    if ((i25 & i15) == 0) {
                                        if (i25 < 4096) {
                                            i26++;
                                            i15 += i25;
                                        }
                                        i24 = i32;
                                        while (i24 > 0) {
                                            i24--;
                                            this.mainPixels[i21] = this.pixelStack[i24];
                                            i16++;
                                            i21++;
                                        }
                                        i27 = i29;
                                        i6 = i30;
                                        i7 = i3;
                                        i8 = i33;
                                        i28 = i31;
                                        i9 = i2;
                                    }
                                }
                                i24 = i32;
                                while (i24 > 0) {
                                }
                                i27 = i29;
                                i6 = i30;
                                i7 = i3;
                                i8 = i33;
                                i28 = i31;
                                i9 = i2;
                            }
                        }
                    }
                    i14 = i25;
                    i13 = i26;
                    i22 = i27;
                    i9 = i2;
                    i23 = i28;
                    break;
                }
                i26 = i9;
                i25 = i8;
                i15 = i10;
                i27 = -1;
            }
            i14 = i25;
            i13 = i26;
            i23 = i28;
            i22 = i27;
            i7 = i7;
            i5 = 1;
            i12 = -1;
        }
        for (int i34 = i21; i34 < i4; i34++) {
            this.mainPixels[i34] = 0;
        }
    }

    private int read() {
        try {
            return this.rawData.get() & 255;
        } catch (Exception unused) {
            this.status = 1;
            return 0;
        }
    }

    private int readBlock() {
        int read = read();
        int i2 = 0;
        if (read > 0) {
            while (i2 < read) {
                int i3 = read - i2;
                try {
                    this.rawData.get(this.block, i2, i3);
                    i2 += i3;
                } catch (Exception e) {
                    Log.w(TAG, "Error Reading Block", e);
                    this.status = 1;
                }
            }
        }
        return i2;
    }

    private Bitmap getNextBitmap() {
        BitmapProvider bitmapProvider = this.bitmapProvider;
        int i2 = this.header.width;
        int i3 = this.header.height;
        Bitmap.Config config = BITMAP_CONFIG;
        Bitmap obtain = bitmapProvider.obtain(i2, i3, config);
        if (obtain == null) {
            obtain = Bitmap.createBitmap(this.header.width, this.header.height, config);
        }
        setAlpha(obtain);
        return obtain;
    }

    private static void setAlpha(Bitmap bitmap) {
        if (Build.VERSION.SDK_INT >= 12) {
            bitmap.setHasAlpha(true);
        }
    }
}
