package net.lingala.zip4j.crypto;

import java.util.Arrays;
import net.lingala.zip4j.crypto.PBKDF2.MacBasedPRF;
import net.lingala.zip4j.crypto.PBKDF2.PBKDF2Engine;
import net.lingala.zip4j.crypto.PBKDF2.PBKDF2Parameters;
import net.lingala.zip4j.crypto.engine.AESEngine;
import net.lingala.zip4j.exception.ZipException;
import net.lingala.zip4j.model.AESExtraDataRecord;
import net.lingala.zip4j.model.LocalFileHeader;
import net.lingala.zip4j.util.Raw;
/* loaded from: classes11.dex */
public class AESDecrypter implements IDecrypter {
    private int KEY_LENGTH;
    private int MAC_LENGTH;
    private int SALT_LENGTH;
    private AESEngine aesEngine;
    private byte[] aesKey;
    private byte[] counterBlock;
    private byte[] derivedPasswordVerifier;
    private byte[] iv;
    private LocalFileHeader localFileHeader;
    private MacBasedPRF mac;
    private byte[] macKey;
    private byte[] storedMac;
    private final int PASSWORD_VERIFIER_LENGTH = 2;
    private int nonce = 1;
    private int loopCount = 0;

    public AESDecrypter(LocalFileHeader localFileHeader, byte[] bArr, byte[] bArr2) throws ZipException {
        if (localFileHeader == null) {
            throw new ZipException("one of the input parameters is null in AESDecryptor Constructor");
        }
        this.localFileHeader = localFileHeader;
        this.storedMac = null;
        this.iv = new byte[16];
        this.counterBlock = new byte[16];
        init(bArr, bArr2);
    }

    private byte[] deriveKey(byte[] bArr, char[] cArr) throws ZipException {
        try {
            return new PBKDF2Engine(new PBKDF2Parameters("HmacSHA1", "ISO-8859-1", bArr, 1000)).deriveKey(cArr, this.KEY_LENGTH + this.MAC_LENGTH + 2);
        } catch (Exception e) {
            throw new ZipException(e);
        }
    }

    private void init(byte[] bArr, byte[] bArr2) throws ZipException {
        int i2;
        LocalFileHeader localFileHeader = this.localFileHeader;
        if (localFileHeader == null) {
            throw new ZipException("invalid file header in init method of AESDecryptor");
        }
        AESExtraDataRecord aesExtraDataRecord = localFileHeader.getAesExtraDataRecord();
        if (aesExtraDataRecord == null) {
            throw new ZipException("invalid aes extra data record - in init method of AESDecryptor");
        }
        int aesStrength = aesExtraDataRecord.getAesStrength();
        if (aesStrength == 1) {
            this.KEY_LENGTH = 16;
            this.MAC_LENGTH = 16;
            i2 = 8;
        } else if (aesStrength != 2) {
            if (aesStrength != 3) {
                throw new ZipException("invalid aes key strength for file: " + this.localFileHeader.getFileName());
            }
            this.KEY_LENGTH = 32;
            this.MAC_LENGTH = 32;
            this.SALT_LENGTH = 16;
            if (this.localFileHeader.getPassword() != null || this.localFileHeader.getPassword().length <= 0) {
                throw new ZipException("empty or null password provided for AES Decryptor");
            }
            byte[] deriveKey = deriveKey(bArr, this.localFileHeader.getPassword());
            if (deriveKey != null) {
                int length = deriveKey.length;
                int i3 = this.KEY_LENGTH;
                int i4 = this.MAC_LENGTH;
                if (length == i3 + i4 + 2) {
                    byte[] bArr3 = new byte[i3];
                    this.aesKey = bArr3;
                    this.macKey = new byte[i4];
                    this.derivedPasswordVerifier = new byte[2];
                    System.arraycopy(deriveKey, 0, bArr3, 0, i3);
                    System.arraycopy(deriveKey, this.KEY_LENGTH, this.macKey, 0, this.MAC_LENGTH);
                    System.arraycopy(deriveKey, this.KEY_LENGTH + this.MAC_LENGTH, this.derivedPasswordVerifier, 0, 2);
                    byte[] bArr4 = this.derivedPasswordVerifier;
                    if (bArr4 == null) {
                        throw new ZipException("invalid derived password verifier for AES");
                    }
                    if (!Arrays.equals(bArr2, bArr4)) {
                        throw new ZipException("Wrong Password for file: " + this.localFileHeader.getFileName(), 5);
                    }
                    this.aesEngine = new AESEngine(this.aesKey);
                    MacBasedPRF macBasedPRF = new MacBasedPRF("HmacSHA1");
                    this.mac = macBasedPRF;
                    macBasedPRF.init(this.macKey);
                    return;
                }
            }
            throw new ZipException("invalid derived key");
        } else {
            this.KEY_LENGTH = 24;
            this.MAC_LENGTH = 24;
            i2 = 12;
        }
        this.SALT_LENGTH = i2;
        if (this.localFileHeader.getPassword() != null) {
        }
        throw new ZipException("empty or null password provided for AES Decryptor");
    }

    @Override // net.lingala.zip4j.crypto.IDecrypter
    public int decryptData(byte[] bArr) throws ZipException {
        return decryptData(bArr, 0, bArr.length);
    }

    @Override // net.lingala.zip4j.crypto.IDecrypter
    public int decryptData(byte[] bArr, int i2, int i3) throws ZipException {
        int i4;
        if (this.aesEngine == null) {
            throw new ZipException("AES not initialized properly");
        }
        int i5 = i2;
        while (true) {
            int i6 = i2 + i3;
            if (i5 >= i6) {
                return i3;
            }
            int i7 = i5 + 16;
            int i8 = i7 <= i6 ? 16 : i6 - i5;
            try {
                this.loopCount = i8;
                this.mac.update(bArr, i5, i8);
                Raw.prepareBuffAESIVBytes(this.iv, this.nonce, 16);
                this.aesEngine.processBlock(this.iv, this.counterBlock);
                for (int i9 = 0; i9 < this.loopCount; i9++) {
                    bArr[i5 + i9] = (byte) (bArr[i4] ^ this.counterBlock[i9]);
                }
                this.nonce++;
                i5 = i7;
            } catch (ZipException e) {
                throw e;
            } catch (Exception e2) {
                throw new ZipException(e2);
            }
        }
    }

    public byte[] getCalculatedAuthenticationBytes() {
        return this.mac.doFinal();
    }

    public int getPasswordVerifierLength() {
        return 2;
    }

    public int getSaltLength() {
        return this.SALT_LENGTH;
    }

    public byte[] getStoredMac() {
        return this.storedMac;
    }

    public void setStoredMac(byte[] bArr) {
        this.storedMac = bArr;
    }
}
