package net.lingala.zip4j.io;

import android.support.v4.media.session.PlaybackStateCompat;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.OutputStream;
import java.io.RandomAccessFile;
import net.lingala.zip4j.exception.ZipException;
import net.lingala.zip4j.util.InternalZipConstants;
import net.lingala.zip4j.util.Raw;
import net.lingala.zip4j.util.Zip4jUtil;
/* loaded from: classes11.dex */
public class SplitOutputStream extends OutputStream {
    private long bytesWrittenForThisPart;
    private int currSplitFileCounter;
    private File outFile;
    private RandomAccessFile raf;
    private long splitLength;
    private File zipFile;

    public SplitOutputStream(File file) throws FileNotFoundException, ZipException {
        this(file, -1L);
    }

    public SplitOutputStream(File file, long j) throws FileNotFoundException, ZipException {
        if (j >= 0 && j < PlaybackStateCompat.ACTION_PREPARE_FROM_SEARCH) {
            throw new ZipException("split length less than minimum allowed split length of 65536 Bytes");
        }
        this.raf = new RandomAccessFile(file, InternalZipConstants.WRITE_MODE);
        this.splitLength = j;
        this.outFile = file;
        this.zipFile = file;
        this.currSplitFileCounter = 0;
        this.bytesWrittenForThisPart = 0L;
    }

    public SplitOutputStream(String str) throws FileNotFoundException, ZipException {
        this(Zip4jUtil.isStringNotNullAndNotEmpty(str) ? new File(str) : null);
    }

    public SplitOutputStream(String str, long j) throws FileNotFoundException, ZipException {
        this(!Zip4jUtil.isStringNotNullAndNotEmpty(str) ? new File(str) : null, j);
    }

    private boolean isHeaderData(byte[] bArr) {
        if (bArr == null || bArr.length < 4) {
            return false;
        }
        int readIntLittleEndian = Raw.readIntLittleEndian(bArr, 0);
        long[] allHeaderSignatures = Zip4jUtil.getAllHeaderSignatures();
        if (allHeaderSignatures == null || allHeaderSignatures.length <= 0) {
            return false;
        }
        for (int i2 = 0; i2 < allHeaderSignatures.length; i2++) {
            if (allHeaderSignatures[i2] != 134695760 && allHeaderSignatures[i2] == readIntLittleEndian) {
                return true;
            }
        }
        return false;
    }

    private void startNextSplitFile() throws IOException {
        try {
            String zipFileNameWithoutExt = Zip4jUtil.getZipFileNameWithoutExt(this.outFile.getName());
            String absolutePath = this.zipFile.getAbsolutePath();
            String str = this.outFile.getParent() == null ? "" : this.outFile.getParent() + System.getProperty("file.separator");
            File file = this.currSplitFileCounter < 9 ? new File(str + zipFileNameWithoutExt + ".z0" + (this.currSplitFileCounter + 1)) : new File(str + zipFileNameWithoutExt + ".z" + (this.currSplitFileCounter + 1));
            this.raf.close();
            if (file.exists()) {
                throw new IOException("split file: " + file.getName() + " already exists in the current directory, cannot rename this file");
            }
            if (!this.zipFile.renameTo(file)) {
                throw new IOException("cannot rename newly created split file");
            }
            this.zipFile = new File(absolutePath);
            this.raf = new RandomAccessFile(this.zipFile, InternalZipConstants.WRITE_MODE);
            this.currSplitFileCounter++;
        } catch (ZipException e) {
            throw new IOException(e.getMessage());
        }
    }

    public boolean checkBuffSizeAndStartNextSplitFile(int i2) throws ZipException {
        if (i2 >= 0) {
            if (isBuffSizeFitForCurrSplitFile(i2)) {
                return false;
            }
            try {
                startNextSplitFile();
                this.bytesWrittenForThisPart = 0L;
                return true;
            } catch (IOException e) {
                throw new ZipException(e);
            }
        }
        throw new ZipException("negative buffersize for checkBuffSizeAndStartNextSplitFile");
    }

    @Override // java.io.OutputStream, java.io.Closeable, java.lang.AutoCloseable
    public void close() throws IOException {
        RandomAccessFile randomAccessFile = this.raf;
        if (randomAccessFile != null) {
            randomAccessFile.close();
        }
    }

    @Override // java.io.OutputStream, java.io.Flushable
    public void flush() throws IOException {
    }

    public int getCurrSplitFileCounter() {
        return this.currSplitFileCounter;
    }

    public long getFilePointer() throws IOException {
        return this.raf.getFilePointer();
    }

    public long getSplitLength() {
        return this.splitLength;
    }

    public boolean isBuffSizeFitForCurrSplitFile(int i2) throws ZipException {
        if (i2 >= 0) {
            long j = this.splitLength;
            return j < PlaybackStateCompat.ACTION_PREPARE_FROM_SEARCH || this.bytesWrittenForThisPart + ((long) i2) <= j;
        }
        throw new ZipException("negative buffersize for isBuffSizeFitForCurrSplitFile");
    }

    public boolean isSplitZipFile() {
        return this.splitLength != -1;
    }

    public void seek(long j) throws IOException {
        this.raf.seek(j);
    }

    @Override // java.io.OutputStream
    public void write(int i2) throws IOException {
        write(new byte[]{(byte) i2}, 0, 1);
    }

    @Override // java.io.OutputStream
    public void write(byte[] bArr) throws IOException {
        write(bArr, 0, bArr.length);
    }

    @Override // java.io.OutputStream
    public void write(byte[] bArr, int i2, int i3) throws IOException {
        long j;
        if (i3 <= 0) {
            return;
        }
        long j2 = this.splitLength;
        if (j2 == -1) {
            this.raf.write(bArr, i2, i3);
            j = this.bytesWrittenForThisPart + i3;
        } else if (j2 < PlaybackStateCompat.ACTION_PREPARE_FROM_SEARCH) {
            throw new IOException("split length less than minimum allowed split length of 65536 Bytes");
        } else {
            long j3 = this.bytesWrittenForThisPart;
            if (j3 >= j2) {
                startNextSplitFile();
                this.raf.write(bArr, i2, i3);
                j = i3;
            } else {
                long j4 = i3;
                if (j3 + j4 > j2) {
                    if (isHeaderData(bArr)) {
                        startNextSplitFile();
                        this.raf.write(bArr, i2, i3);
                    } else {
                        this.raf.write(bArr, i2, (int) (this.splitLength - this.bytesWrittenForThisPart));
                        startNextSplitFile();
                        RandomAccessFile randomAccessFile = this.raf;
                        long j5 = this.splitLength;
                        long j6 = this.bytesWrittenForThisPart;
                        randomAccessFile.write(bArr, ((int) (j5 - j6)) + i2, (int) (j4 - (j5 - j6)));
                        j4 -= this.splitLength - this.bytesWrittenForThisPart;
                    }
                    this.bytesWrittenForThisPart = j4;
                    return;
                }
                this.raf.write(bArr, i2, i3);
                j = this.bytesWrittenForThisPart + j4;
            }
        }
        this.bytesWrittenForThisPart = j;
    }
}
